/*-
 * Copyright (c) 2000-2002 Andrey Simonenko
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef lint
static const char rcsid[] =
  "@(#)$Id: debug.c,v 1.6 2002/12/19 18:56:02 simon Exp $";
#endif /* !lint */

#include <syslog.h>
#include <stdarg.h>

#include "debug.h"
#include "system.h"

#ifdef __OpenBSD__
# include "kpf.h"
#endif

#ifdef __FreeBSD__
# include "kipfw.h"
# include "kip6fw.h"
#endif

int		debug_exec, debug_limit, debug_time, debug_lock,
		debug_include;

static int	debug_exec_bkp, debug_limit_bkp, debug_time_bkp,
		debug_lock_bkp, debug_include_bkp;

#ifdef WITH_IPFW
int		debug_ipfw;
static int	debug_ipfw_bkp;
#endif

#ifdef WITH_IP6FW
int		debug_ip6fw;
static int	debug_ip6fw_bkp;
#endif

#ifdef WITH_IPFIL
int		debug_ipfil;
static int	debug_ipfil_bkp;
#endif

#ifdef WITH_PF
int		debug_pf;
static int	debug_pf_bkp;
#endif

/*
 * Reset all debug variables (i.e. set them to default value).
 */
void
reset_debug(void)
{
#ifdef WITH_IPFW
	debug_ipfw = 
#endif
#ifdef WITH_IP6FW
	debug_ip6fw =
#endif
#ifdef WITH_PF
	debug_pf =
#endif
#ifdef WITH_IPFIL
	debug_ipfil =
#endif
	debug_exec = debug_limit = debug_time = debug_lock = 0;
	debug_include = 1;
}

/*
 * Backup current values of debug_* parameters.
 */
void
backup_debug(void)
{
#define BACKUP(param)	param ## _bkp = param

#ifdef WITH_IPFW
	BACKUP(debug_ipfw);
#endif
#ifdef WITH_IP6FW
	BACKUP(debug_ip6fw);
#endif
#ifdef WITH_PF
	BACKUP(debug_pf);
#endif
#ifdef WITH_IPFIL
	BACKUP(debug_ipfil);
#endif
	BACKUP(debug_exec);
	BACKUP(debug_limit);
	BACKUP(debug_time);
	BACKUP(debug_lock);
	BACKUP(debug_include);
}

/*
 * Restore values of backup_* parameters from backuped copies.
 */
void
restore_debug(void)
{
#define RESTORE(param)	param = param ## _bkp

#ifdef WITH_IPFW
	RESTORE(debug_ipfw);
#endif
#ifdef WITH_IP6FW
	RESTORE(debug_ip6fw);
#endif
#ifdef WITH_PF
	RESTORE(debug_pf);
#endif
#ifdef WITH_IPFIL
	RESTORE(debug_ipfil);
#endif
	RESTORE(debug_exec);
	RESTORE(debug_limit);
	RESTORE(debug_time);
	RESTORE(debug_lock);
	RESTORE(debug_include);
}
